@@ -36,23 +36,7 @@ void trainWrapperR(float *data, int data_length,
   coreData.globalBmus_size = nVectorsPerRank*int(ceil(nVectors/(double)nVectorsPerRank))*2;
   if (itask == 0) {
       coreData.globalBmus = new int[coreData.globalBmus_size];
-
-//      if (initialCodebookFilename.empty()){
-          initializeCodebook(0, coreData.codebook, nSomX, nSomY, nDimensions);
-//      } else {
-//          unsigned int nSomXY = 0;
-//          unsigned int tmpNDimensions = 0;
-//          delete [] coreData.codebook;
-//          coreData.codebook = readMatrix(initialCodebookFilename, nSomXY, tmpNDimensions);
-//          if (tmpNDimensions != nDimensions) {
-//              cerr << "Dimension of initial codebook does not match data!\n";
-//              my_abort(5);
-//          } else if (nSomXY / nSomY != nSomX) {
-//              cerr << "Dimension of initial codebook does not match specified SOM grid!\n";
-//              my_abort(6);
-//          }
-//          cout << "Read initial codebook: " << initialCodebookFilename << "\n";
-//      }
+      initializeCodebook(0, coreData.codebook, nSomX, nSomY, nDimensions);
   }
   ///
   /// Parameters for SOM
@@ -115,16 +99,11 @@ void trainWrapperR(float *data, int data_length,
 RcppExport SEXP Rtrain(SEXP data_p,
                        SEXP nEpoch_p,
                        SEXP nSomX_p, SEXP nSomY_p,
-                       //            SEXP nDimensions, SEXP nVectors,
                        SEXP radius0_p, SEXP radiusN_p,
                        SEXP radiusCooling_p,
                        SEXP scale0_p, SEXP scaleN_p,
                        SEXP scaleCooling_p, SEXP snapshots_p,
                        SEXP kernelType_p, SEXP mapType_p)
-//                       SEXP initialCodebookFilename_p)
-//            SEXP codebook, SEXP codebook_size,
-//            SEXP globalBmus, SEXP globalBmus_size,
-//            SEXP uMatrix, SEXP uMatrix_size)
 {
   Rcpp::NumericMatrix dataMatrix(data_p);
   int nVectors = dataMatrix.rows();
@@ -141,7 +120,6 @@ RcppExport SEXP Rtrain(SEXP data_p,
   unsigned int snapshots = (unsigned int) as<int>(snapshots_p);
   unsigned int kernelType = (unsigned int) as<int>(kernelType_p);
   string mapType = as<string>(mapType_p);
-//  string initialCodebookFilename = as<string>(initialCodebookFilename_p);
   int data_length = nVectors * nDimensions;
   float* data = new float[data_length];
   // convert matrix to data c float array
@@ -181,6 +159,9 @@ RcppExport SEXP Rtrain(SEXP data_p,
           uMatrix_vec(i) = uMatrix[i];
         }
     }
+  delete[] codebook;
+  delete[] globalBmus;
+  delete[] uMatrix;
   return Rcpp::List::create(Rcpp::Named("codebook") = codebook_vec,
                             Rcpp::Named("globalBmus") = globalBmus_vec,
                             Rcpp::Named("uMatrix") = uMatrix_vec);;
